==================
Beginners Tutorial
==================

Welcome to the PyMoskito Tutorial! It is intended to introduce new users to the
toolbox.
For more detailed descriptions, please see the
:doc:`Users Guide <../../guide/index>` or the
:doc:`Modules Reference <../../modules/index>`.

Within this tutorial, an inverse pendulum on cart will be simulated and
stabilized.
With the help of PyMoskito, the model as well as the controller will be tested
by simulating the open and closed control loop.

All code is written in Python. If you want to refresh or expand 
your knowledge about this language, see e.g. the `Python Tutorial`_.

.. toctree::
  :maxdepth: 2

  intro
  system
  model
  starting
  test_model
  controller
  test_controller
  outro

.. _`Python Tutorial`: https://docs.python.org/3/tutorial/index.html